| Title: | IMDb Film Ratings from the Summer of 2022 |
|---|---|
| Description: | Average rating and number of votes reported by IMDb for films and shorts with over 100 votes in 2022. The data are analysed in Chapter 3 of the Book 'Getting (more out of) Graphics' (Antony Unwin, CRC Press 2024). |
| Authors: | Antony Unwin [aut, cre, cph] |
| Maintainer: | Antony Unwin <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.0 |
| Built: | 2026-06-04 09:50:00 UTC |
| Source: | https://github.com/cran/FilmsGmooG |
Average ratings reported by IMDb of films and shorts with over 100 ratings from summer 2022.
data(films22)data(films22)
A data frame with 124667 observations on the following 8 variables.
nrID number of film
averageRatingAverage rating of film
numVotesHow many rated the film
titleTypemovie or short
primaryTitleTitle of film
genresA combination of up to three film genres for each film
yearYear of release (from 1874 to 2022)
runtimeruntime in minutes
This dataset is used in "Looking at the movies", Chapter 3 of "Getting (more out of) Graphics".
data(films22, package="FilmsGmooG") with(films22, table(titleType))data(films22, package="FilmsGmooG") with(films22, table(titleType))
The film ratings dataset is bigger than 1Mb, so it is provided in this package.
Most of the datasets analysed in the book are available in GmooG and other R packages.
Antony Unwin [email protected]
Frequencies of ratings given for two famous films, as reported in July 2022
data(RBSS)data(RBSS)
A data frame with 20 observations on the following 3 variables.
RatingRatings from 1 to 10
FilmName of film
FreqNumber giving that rating for that film
This dataset and the dataset RBSSr are both used in Chapter 3, "Looking at the movies".
data(RBSS, package="FilmsGmooG") RBSSdata(RBSS, package="FilmsGmooG") RBSS
Average ratings for two famous films, as reported in July 2022
data(RBSSr)data(RBSSr)
A data frame with 16 observations on the following 5 variables.
FilmName of film
SexMale or Female
AgeOne of four age groups, <18, 18-29, 30-44, 45+
FreqNumber rating that film
AvRatingAverage rating
This dataset and the dataset RBSS are both used in Chapter 3, "Looking at the movies".
data(RBSSr, package="FilmsGmooG") RBSSrdata(RBSSr, package="FilmsGmooG") RBSSr